/**
  *  \file planetscentral/talk/cmdforum.h
  *  \brief Talk: FORUM commands
  */
#ifndef C2SERVER_PLANETSCENTRAL_TALK_CMDFORUM_H
#define C2SERVER_PLANETSCENTRAL_TALK_CMDFORUM_H

#include "cpluslib/types.h"

class TalkConnection;
class IntArgBlock;
class DbIntSet;

class ListParams {
 public:
    struct SortParams {
        const char* name;
        const char* sortKey;
        bool lexicographically;
    };
    static const SortParams threadSortKeys[];
    static const SortParams postSortKeys[];
    static const SortParams forumSortKeys[];
    static const SortParams pmSortKeys[];

    ListParams();
    void parse(IntArgBlock& args, bool withId, const SortParams* sortParams);
    void exec(TalkConnection& conn, DbIntSet set);
    int32_t getId();

 private:
    int32_t id;
    int32_t start;
    int32_t count;
    int32_t item;
    enum Mode { WantAll, WantRange, WantSize, WantMemberCheck };
    Mode mode;
    const SortParams* sortKey;
};

void doForumAdd(TalkConnection& conn, IntArgBlock& args);
void doForumSet(TalkConnection& conn, IntArgBlock& args);
void doForumGet(TalkConnection& conn, IntArgBlock& args);
void doForumStat(TalkConnection& conn, IntArgBlock& args);
void doForumMStat(TalkConnection& conn, IntArgBlock& args);
void doForumPerms(TalkConnection& conn, IntArgBlock& args);
void doForumSize(TalkConnection& conn, IntArgBlock& args);
void doForumListThreads(TalkConnection& conn, IntArgBlock& args);
void doForumListStickyThreads(TalkConnection& conn, IntArgBlock& args);
void doForumListPosts(TalkConnection& conn, IntArgBlock& args);

#endif
